package main

import (
	"bufio"
	"fmt"
	"log"
	"net/http"
	"net/url"
)

func main() {
	log.SetFlags(log.Ltime)

	http.HandleFunc("/foo-proxy", handler)

	log.Println("serving on port 8081...")
	log.Fatal(http.ListenAndServe(":8081", nil))
}

func handler(w http.ResponseWriter, r *http.Request) {
	defer func() {
		fmt.Println("left handler func")
	}()

	log.Println("/foo-proxy")

	c := http.Client{
		Transport: http.DefaultTransport,
	}

	purl, err := url.Parse(fmt.Sprintf("http://localhost:7999/foo"))
	r.URL = purl

	log.Println("making request")
	resp, err := c.Transport.RoundTrip(r)
	if err != nil {
		log.Fatal(err)
	}
	log.Println("response headers: ", resp.Header)

	flusher, ok := w.(http.Flusher)
	if !ok {
		log.Fatal("isn't a flusher")
	}

	reader := bufio.NewReader(resp.Body)
	for {
		l, _, err := reader.ReadLine()
		if err != nil {
			log.Fatal("failed to read bytes: ", err)
		}
		fmt.Fprintln(w, string(l))
		flusher.Flush()
	}
}

func copyHeader(dst, src http.Header) {
	for k, vv := range src {
		for _, v := range vv {
			dst.Add(k, v)
		}
	}
}
